"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.AuthenticationStatus = void 0;
const js_cookie_1 = __importDefault(require("js-cookie"));
const Auth_1 = __importDefault(require("./comm/coreServices/Auth"));
var AuthenticationStatus;
(function (AuthenticationStatus) {
    AuthenticationStatus["NONE"] = "NONE";
    AuthenticationStatus["CHECKING"] = "CHECKING";
    AuthenticationStatus["AUTHENTICATED"] = "AUTHENTICATED";
    AuthenticationStatus["UNAUTHENTICATED"] = "UNAUTHENTICATED";
    AuthenticationStatus["ERROR"] = "ERROR";
})(AuthenticationStatus = exports.AuthenticationStatus || (exports.AuthenticationStatus = {}));
class Auth {
    constructor(url) {
        this.url = url;
    }
    checkAuth() {
        return __awaiter(this, void 0, void 0, function* () {
            const token = js_cookie_1.default.get('kbase_session');
            if (!token) {
                return {
                    status: AuthenticationStatus.UNAUTHENTICATED
                };
            }
            const auth = new Auth_1.default({ url: this.url });
            try {
                const account = yield auth.getMe(token);
                const roles = account.roles.map(({ id, desc }) => id);
                return {
                    status: AuthenticationStatus.AUTHENTICATED,
                    userAuthentication: {
                        token,
                        username: account.user,
                        realname: account.display,
                        roles
                    }
                };
            }
            catch (err) {
                return {
                    status: AuthenticationStatus.ERROR,
                    message: err.message
                };
            }
        });
    }
}
exports.default = Auth;
//# sourceMappingURL=Auth.js.map