import { JSONObject, JSONValue, JSONArray } from '../../json';
export interface JSONRPCRequestOptions {
    func: string;
    params: any;
    timeout?: number;
    token?: string;
}
export interface JSONRPCRequest {
    method: string;
    jsonrpc: '2.0';
    id: string;
    params: Array<JSONValue>;
    context?: any;
}
export interface JSONRPCErrorInfo {
    code: string;
    status?: number;
    message: string;
    detail?: string;
    data?: any;
}
export interface JSONRPCClientParams {
    url: string;
    timeout: number;
    token?: string;
}
export type JSONRPCParams = JSONArray | JSONObject;
export interface JSONPayload {
    jsonrpc: string;
    method: string;
    id: string;
    params?: JSONRPCParams;
}
export interface JSONRPC20Error {
    name: string;
    code: number;
    message: string;
    error: JSONValue;
}
export type JSONRPCError = JSONRPC20Error;
export declare class JSONRPC20Exception extends Error {
    error: JSONRPC20Error;
    constructor(error: JSONRPCError);
}
export interface JSONRPCResponseBase {
    jsonrpc: '2.0';
    id?: string;
}
export interface JSONRPCResponseResult extends JSONRPCResponseBase {
    result: JSONValue;
}
export interface JSONRPCResponseError extends JSONRPCResponseBase {
    error: JSONRPCError;
}
export type JSONRPCResponse = JSONRPCResponseResult | JSONRPCResponseError;
export declare class JSONRPCClient {
    url: string;
    timeout: number;
    token?: string;
    constructor({ url, timeout, token }: JSONRPCClientParams);
    protected makePayload(method: string, params?: JSONRPCParams): JSONPayload;
    callMethod(method: string, params?: JSONRPCParams, { timeout }?: {
        timeout?: number;
    }): Promise<JSONValue>;
}
