import { ServiceClient } from "../JSONRPC11/ServiceClient";
import { EpochTime, SDKBoolean } from "../types";
import { JSONObject, JSONObjectOf } from "../../json";
export interface ObjectIdentity {
    workspace?: string;
    wsid?: number;
    name?: string;
    objid?: string;
    ver?: number;
    ref?: string;
}
export interface WorkspaceIdentity {
    workspace?: string;
    id?: number;
}
export interface ObjectSpecification {
    workspace?: string;
    wsid?: number;
    name?: string;
    objid?: number;
    ver?: number;
    ref?: string;
    obj_path?: Array<ObjectIdentity>;
    obj_ref_path?: Array<string>;
    to_obj_path?: Array<ObjectIdentity>;
    to_obj_ref_path?: Array<string>;
    find_reference_path?: number;
    included?: string;
    strict_maps?: number;
    strict_arrays?: number;
}
export interface GetObjectInfo3Params {
    objects: Array<ObjectSpecification>;
    includeMetadata?: number;
    ignoreErrors?: number;
}
export type ObjectInfo = [
    number,
    string,
    string,
    string,
    number,
    string,
    number,
    string,
    string,
    number,
    Metadata
];
export type WorkspaceInfo = [
    number,
    string,
    string,
    string,
    number,
    string,
    string,
    string,
    Metadata
];
export type Metadata = JSONObjectOf<string>;
export interface GetObjectInfo3Result extends JSONObject {
    infos: Array<ObjectInfo>;
    paths: Array<Array<string>>;
}
export interface GetWorkspaceInfoParams extends WorkspaceIdentity {
}
export interface GetWorkspaceInfoResult {
}
export type TimeString = string;
export interface ListWorkspaceInfoParams {
    perm?: string;
    owners?: Array<string>;
    meta?: Metadata;
    after?: TimeString;
    before?: TimeString;
    after_epoch?: EpochTime;
    before_epoch?: EpochTime;
    excludeGloba?: SDKBoolean;
    showDeleted?: SDKBoolean;
    showOnlyDeleted?: SDKBoolean;
}
export type ListWorkspaceInfoResult = Array<WorkspaceInfo>;
export default class WorkspaceClient extends ServiceClient {
    module: string;
    ver(): Promise<string>;
    get_object_info3(params: GetObjectInfo3Params): Promise<GetObjectInfo3Result>;
    get_workspace_info(params: GetWorkspaceInfoParams): Promise<WorkspaceInfo>;
    list_workspace_info(params: ListWorkspaceInfoParams): Promise<ListWorkspaceInfoResult>;
}
